==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerHTTPHeadersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IngressControllerHTTPHeadersFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent<A>{
  public IngressControllerHTTPHeadersFluentImpl() {
  }
  public IngressControllerHTTPHeadersFluentImpl(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeaders instance) {
    this.withForwardedHeaderPolicy(instance.getForwardedHeaderPolicy()); 
    this.withHeaderNameCaseAdjustments(instance.getHeaderNameCaseAdjustments()); 
    this.withUniqueId(instance.getUniqueId()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String forwardedHeaderPolicy;
  private java.util.List<java.lang.String> headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder uniqueId;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getForwardedHeaderPolicy() {
    return this.forwardedHeaderPolicy;
  }
  public A withForwardedHeaderPolicy(java.lang.String forwardedHeaderPolicy) {
    this.forwardedHeaderPolicy=forwardedHeaderPolicy; return (A) this;
  }
  public java.lang.Boolean hasForwardedHeaderPolicy() {
    return this.forwardedHeaderPolicy != null;
  }
  
  /**
   * Method is deprecated. use withForwardedHeaderPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewForwardedHeaderPolicy(java.lang.String arg0) {
    return (A)withForwardedHeaderPolicy(new String(arg0));
  }
  public A addToHeaderNameCaseAdjustments(java.lang.Integer index,java.lang.String item) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    this.headerNameCaseAdjustments.add(index, item);
    return (A)this;
  }
  public A setToHeaderNameCaseAdjustments(java.lang.Integer index,java.lang.String item) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    this.headerNameCaseAdjustments.set(index, item); return (A)this;
  }
  public A addToHeaderNameCaseAdjustments(java.lang.String... items) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.headerNameCaseAdjustments.add(item);} return (A)this;
  }
  public A addAllToHeaderNameCaseAdjustments(java.util.Collection<java.lang.String> items) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.headerNameCaseAdjustments.add(item);} return (A)this;
  }
  public A removeFromHeaderNameCaseAdjustments(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.headerNameCaseAdjustments!= null){ this.headerNameCaseAdjustments.remove(item);}} return (A)this;
  }
  public A removeAllFromHeaderNameCaseAdjustments(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.headerNameCaseAdjustments!= null){ this.headerNameCaseAdjustments.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getHeaderNameCaseAdjustments() {
    return this.headerNameCaseAdjustments;
  }
  public java.lang.String getHeaderNameCaseAdjustment(java.lang.Integer index) {
    return this.headerNameCaseAdjustments.get(index);
  }
  public java.lang.String getFirstHeaderNameCaseAdjustment() {
    return this.headerNameCaseAdjustments.get(0);
  }
  public java.lang.String getLastHeaderNameCaseAdjustment() {
    return this.headerNameCaseAdjustments.get(headerNameCaseAdjustments.size() - 1);
  }
  public java.lang.String getMatchingHeaderNameCaseAdjustment(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: headerNameCaseAdjustments) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingHeaderNameCaseAdjustment(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: headerNameCaseAdjustments) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withHeaderNameCaseAdjustments(java.util.List<java.lang.String> headerNameCaseAdjustments) {
    if (headerNameCaseAdjustments != null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : headerNameCaseAdjustments){this.addToHeaderNameCaseAdjustments(item);}} else { this.headerNameCaseAdjustments = null;} return (A) this;
  }
  public A withHeaderNameCaseAdjustments(java.lang.String... headerNameCaseAdjustments) {
    if (this.headerNameCaseAdjustments != null) {this.headerNameCaseAdjustments.clear();}
    if (headerNameCaseAdjustments != null) {for (java.lang.String item :headerNameCaseAdjustments){ this.addToHeaderNameCaseAdjustments(item);}} return (A) this;
  }
  public java.lang.Boolean hasHeaderNameCaseAdjustments() {
    return headerNameCaseAdjustments != null && !headerNameCaseAdjustments.isEmpty();
  }
  public A addNewHeaderNameCaseAdjustment(java.lang.String arg0) {
    return (A)addToHeaderNameCaseAdjustments(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildUniqueId instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy getUniqueId() {
    return this.uniqueId!=null?this.uniqueId.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy buildUniqueId() {
    return this.uniqueId!=null?this.uniqueId.build():null;
  }
  public A withUniqueId(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy uniqueId) {
    _visitables.get("uniqueId").remove(this.uniqueId);
    if (uniqueId!=null){ this.uniqueId= new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder(uniqueId); _visitables.get("uniqueId").add(this.uniqueId);} return (A) this;
  }
  public java.lang.Boolean hasUniqueId() {
    return this.uniqueId != null;
  }
  public A withNewUniqueId(java.lang.String format,java.lang.String name) {
    return (A)withUniqueId(new IngressControllerHTTPUniqueIdHeaderPolicy(format, name));
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueId() {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluentImpl.UniqueIdNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueIdLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy item) {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluentImpl.UniqueIdNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editUniqueId() {
    return withNewUniqueIdLike(getUniqueId());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueId() {
    return withNewUniqueIdLike(getUniqueId() != null ? getUniqueId(): new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueIdLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy item) {
    return withNewUniqueIdLike(getUniqueId() != null ? getUniqueId(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressControllerHTTPHeadersFluentImpl that = (IngressControllerHTTPHeadersFluentImpl) o;
    if (forwardedHeaderPolicy != null ? !forwardedHeaderPolicy.equals(that.forwardedHeaderPolicy) :that.forwardedHeaderPolicy != null) return false;
    if (headerNameCaseAdjustments != null ? !headerNameCaseAdjustments.equals(that.headerNameCaseAdjustments) :that.headerNameCaseAdjustments != null) return false;
    if (uniqueId != null ? !uniqueId.equals(that.uniqueId) :that.uniqueId != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(forwardedHeaderPolicy,  headerNameCaseAdjustments,  uniqueId,  additionalProperties,  super.hashCode());
  }
  public class UniqueIdNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<N>> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    UniqueIdNestedImpl(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder(this, item);
    }
    UniqueIdNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder builder;
    public N and() {
      return (N) IngressControllerHTTPHeadersFluentImpl.this.withUniqueId(builder.build());
    }
    public N endUniqueId() {
      return and();
    }
    
  }
  
}

==> openshift-model-operator-5.12.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/IngressControllerHTTPHeadersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class IngressControllerHTTPHeadersFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent<A>{
  public IngressControllerHTTPHeadersFluentImpl() {
  }
  public IngressControllerHTTPHeadersFluentImpl(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeaders instance) {
    this.withForwardedHeaderPolicy(instance.getForwardedHeaderPolicy()); 
    this.withHeaderNameCaseAdjustments(instance.getHeaderNameCaseAdjustments()); 
    this.withUniqueId(instance.getUniqueId()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String forwardedHeaderPolicy;
  private java.util.List<java.lang.String> headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();
  private io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder uniqueId;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getForwardedHeaderPolicy() {
    return this.forwardedHeaderPolicy;
  }
  public A withForwardedHeaderPolicy(java.lang.String forwardedHeaderPolicy) {
    this.forwardedHeaderPolicy=forwardedHeaderPolicy; return (A) this;
  }
  public java.lang.Boolean hasForwardedHeaderPolicy() {
    return this.forwardedHeaderPolicy != null;
  }
  
  /**
   * Method is deprecated. use withForwardedHeaderPolicy instead.
   */
  @java.lang.Deprecated
  public A withNewForwardedHeaderPolicy(java.lang.String arg0) {
    return (A)withForwardedHeaderPolicy(new String(arg0));
  }
  public A addToHeaderNameCaseAdjustments(java.lang.Integer index,java.lang.String item) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    this.headerNameCaseAdjustments.add(index, item);
    return (A)this;
  }
  public A setToHeaderNameCaseAdjustments(java.lang.Integer index,java.lang.String item) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    this.headerNameCaseAdjustments.set(index, item); return (A)this;
  }
  public A addToHeaderNameCaseAdjustments(java.lang.String... items) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.headerNameCaseAdjustments.add(item);} return (A)this;
  }
  public A addAllToHeaderNameCaseAdjustments(java.util.Collection<java.lang.String> items) {
    if (this.headerNameCaseAdjustments == null) {this.headerNameCaseAdjustments = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.headerNameCaseAdjustments.add(item);} return (A)this;
  }
  public A removeFromHeaderNameCaseAdjustments(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.headerNameCaseAdjustments!= null){ this.headerNameCaseAdjustments.remove(item);}} return (A)this;
  }
  public A removeAllFromHeaderNameCaseAdjustments(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.headerNameCaseAdjustments!= null){ this.headerNameCaseAdjustments.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getHeaderNameCaseAdjustments() {
    return this.headerNameCaseAdjustments;
  }
  public java.lang.String getHeaderNameCaseAdjustment(java.lang.Integer index) {
    return this.headerNameCaseAdjustments.get(index);
  }
  public java.lang.String getFirstHeaderNameCaseAdjustment() {
    return this.headerNameCaseAdjustments.get(0);
  }
  public java.lang.String getLastHeaderNameCaseAdjustment() {
    return this.headerNameCaseAdjustments.get(headerNameCaseAdjustments.size() - 1);
  }
  public java.lang.String getMatchingHeaderNameCaseAdjustment(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: headerNameCaseAdjustments) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingHeaderNameCaseAdjustment(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: headerNameCaseAdjustments) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withHeaderNameCaseAdjustments(java.util.List<java.lang.String> headerNameCaseAdjustments) {
    if (headerNameCaseAdjustments != null) {this.headerNameCaseAdjustments = new java.util.ArrayList(); for (java.lang.String item : headerNameCaseAdjustments){this.addToHeaderNameCaseAdjustments(item);}} else { this.headerNameCaseAdjustments = null;} return (A) this;
  }
  public A withHeaderNameCaseAdjustments(java.lang.String... headerNameCaseAdjustments) {
    if (this.headerNameCaseAdjustments != null) {this.headerNameCaseAdjustments.clear();}
    if (headerNameCaseAdjustments != null) {for (java.lang.String item :headerNameCaseAdjustments){ this.addToHeaderNameCaseAdjustments(item);}} return (A) this;
  }
  public java.lang.Boolean hasHeaderNameCaseAdjustments() {
    return headerNameCaseAdjustments != null && !headerNameCaseAdjustments.isEmpty();
  }
  public A addNewHeaderNameCaseAdjustment(java.lang.String arg0) {
    return (A)addToHeaderNameCaseAdjustments(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildUniqueId instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy getUniqueId() {
    return this.uniqueId!=null?this.uniqueId.build():null;
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy buildUniqueId() {
    return this.uniqueId!=null?this.uniqueId.build():null;
  }
  public A withUniqueId(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy uniqueId) {
    _visitables.get("uniqueId").remove(this.uniqueId);
    if (uniqueId!=null){ this.uniqueId= new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder(uniqueId); _visitables.get("uniqueId").add(this.uniqueId);} return (A) this;
  }
  public java.lang.Boolean hasUniqueId() {
    return this.uniqueId != null;
  }
  public A withNewUniqueId(java.lang.String format,java.lang.String name) {
    return (A)withUniqueId(new IngressControllerHTTPUniqueIdHeaderPolicy(format, name));
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueId() {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluentImpl.UniqueIdNestedImpl();
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> withNewUniqueIdLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy item) {
    return new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluentImpl.UniqueIdNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editUniqueId() {
    return withNewUniqueIdLike(getUniqueId());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueId() {
    return withNewUniqueIdLike(getUniqueId() != null ? getUniqueId(): new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder().build());
  }
  public io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<A> editOrNewUniqueIdLike(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy item) {
    return withNewUniqueIdLike(getUniqueId() != null ? getUniqueId(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressControllerHTTPHeadersFluentImpl that = (IngressControllerHTTPHeadersFluentImpl) o;
    if (forwardedHeaderPolicy != null ? !forwardedHeaderPolicy.equals(that.forwardedHeaderPolicy) :that.forwardedHeaderPolicy != null) return false;
    if (headerNameCaseAdjustments != null ? !headerNameCaseAdjustments.equals(that.headerNameCaseAdjustments) :that.headerNameCaseAdjustments != null) return false;
    if (uniqueId != null ? !uniqueId.equals(that.uniqueId) :that.uniqueId != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(forwardedHeaderPolicy,  headerNameCaseAdjustments,  uniqueId,  additionalProperties,  super.hashCode());
  }
  public class UniqueIdNestedImpl<N> extends io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyFluentImpl<io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<N>> implements io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPHeadersFluent.UniqueIdNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    UniqueIdNestedImpl(io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicy item) {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder(this, item);
    }
    UniqueIdNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder(this);
    }
    io.fabric8.openshift.api.model.operator.v1.IngressControllerHTTPUniqueIdHeaderPolicyBuilder builder;
    public N and() {
      return (N) IngressControllerHTTPHeadersFluentImpl.this.withUniqueId(builder.build());
    }
    public N endUniqueId() {
      return and();
    }
    
  }
  
}
